#include <cstdio>
#include <iostream>
#include <vector>
#include <stack>
#include <cstdlib>
#include <algorithm>
#include <climits>
using namespace std;

int k, n;
vector<char> braces;
vector<pair<int, int>> matches;
vector<vector<pair<int, int>>> upToLen;
vector<vector<int>> pairsWithin;

int len(pair<int, int> x){ return x.second - x.first + 1; }

bool by_len(pair<int, int> x, pair<int, int> y)
{
    return
        len(x) < len(y) ||
        (len(x) == len(y) && x.first < y.first);
}

bool by_last_len(const vector<pair<int, int>> &x, const vector<pair<int, int>> &y)
{
    for(int i = x.size()-1;i>=0;i--)
    {
        int lenX = len(x[i]);
        int lenY = len(y[i]);
        if(lenX < lenY)return true;
        if(lenX > lenY)return false;
    }
    return false;
}

void read()
{
    string s;
    braces.push_back('_');
    cin>>s;
    n = s.size();
    for(char x : s)braces.push_back(x);
    cin>>k;
}

void match()
{
    int maxLen = 0;
    stack<pair<char, int>> bracks;
    for(int i = 1;i<=n;i++)
    {
        char c = braces[i];
        if(c=='(')bracks.emplace(c, i);
        else
        {
            if(!bracks.empty() && bracks.top().first == '(')
            {
                matches.emplace_back(bracks.top().second, i);
                maxLen = max(maxLen, len(matches.back()));
                bracks.pop();
            }
        }
    }

    upToLen.resize(maxLen + 1);

    for(auto match : matches)///N
    {
        int l = len(match);
        for(int i=l;i<=maxLen;i++)///N
        {
            upToLen[i].push_back(match);
        }
    }
    ///N ^ 2

    for(auto &x : upToLen)///N
    {
        sort(x.begin(), x.end());///n * log(N)
    }
    /// N ^ 2 * log(n)
}

void calculate()
{
    pairsWithin.resize(n+1, vector<int>(n+1, 0));
    for(auto match : matches)
    {
        for(int i=1;i<=match.first;i++)
        {
            for(int j=match.second;j<=n;j++)
            {
                //printf("calculating %d %d\n", i, j);
                pairsWithin[i][j]++;
            }
        }
    }
}

int minSum = INT_MAX;

vector<vector<pair<int, int>>> goStacks;

int currentSum = 0;
vector<pair<int, int>> goStack;
void go(int from, int to)
{
    if(currentSum > minSum) return;
    //printf("   go(%d, %d)", from, to);
    goStack.emplace_back(from, to);
    currentSum+=pairsWithin[from][to];

    if(goStack.size()==k)
    {
        int lastLen = len(goStack.back());
        if(currentSum < minSum)
        {
            minSum = currentSum;
            goStacks.clear();
            goStacks.push_back(goStack);
        }
        else if(currentSum == minSum)
        {
            goStacks.push_back(goStack);
        }

        /*
        printf("%d\n", currentSum);
        for(auto x : goStack)
        {
            printf("[%d %d]\n", x.first, x.second);
        }
        puts("\n\n");
        */

    }
    else
    {
        if(goStack.size()<k-1)
        {
            for(int to1 = to+1;to1<=n;to1++)
            {
                go(to+1, to1);
            }
        }
        else
        {
            if(to+1<=n)
            {
                go(to+1, n);
            }
            else {}
        }
    }

    currentSum-=pairsWithin[from][to];
    goStack.pop_back();
}

void go()
{
    for(int i=1;i<=n;i++)go(1, i);
    sort(goStacks.begin(), goStacks.end(), by_last_len);
}

void print_pairs(int from, int to)
{
    int l = min(to - from + 1, (int)upToLen.size()-1);

    vector<int> indices;

    for(auto &x : upToLen[l])
    {
        if(x.first > to)break;
        if(x.first>=from && x.second<=to)
        {
            indices.push_back(x.first);
            indices.push_back(x.second);
        }
    }

    sort(indices.begin(), indices.end());

    for(int x : indices)printf("%d ", x);
}

void print_stack(const vector<pair<int, int>> &s)
{
    for(int i=0;i<s.size();i++)
    {
        printf(
            "%d,[%d,%d],%d:",
            i+1,
            s[i].first, s[i].second,
            pairsWithin[s[i].first][s[i].second] * 2
        );

        print_pairs(s[i].first, s[i].second);

        putchar('\n');
    }

    //putchar('\n');
}

void solve()
{
    match();
    calculate();
    go();

    printf("%d\n", minSum * 2);
    print_stack(goStacks.back());
    print_stack(goStacks.front());

    /*
    for(int i=1;i<=n;i++)
    {
        for(int j=1;j<=n;j++)
        {
            printf("%d ", pairsWithin[i][j]);
        }
        putchar('\n');
    }
    */
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    read();
    solve();
    return EXIT_SUCCESS;
}
/**

()()
3


(()(()
2

(((((((((())))))))))(((((((((())))))))))
3

**/
