#include <iostream>
#include <cstdint>
#include <vector>
#include <utility>
#include <cassert>

struct GVertex {
	std::vector<GVertex*> edges;
	GVertex *loopRoot;
	uint32_t depth;

	uint32_t rootDist;
	uint32_t loopLen;

	GVertex(): loopRoot(nullptr), depth(0), rootDist(0), loopLen(0) {}
	GVertex* dfs();
};

std::vector<GVertex> graph;
GVertex *start, *end;

GVertex* GVertex::dfs() {
	for (GVertex *v : edges) {
		if (v->depth) {
			//makes sure to not count the parent unless it's an actuall loop
			if ((loopRoot == nullptr) || (v->depth <= loopRoot->depth)) {
				loopRoot = v;
				loopLen = std::max(loopLen, depth - loopRoot->depth + 1);
			}
		} else {
			v->depth = depth + 1;
			GVertex *t = v->dfs();
			if (loopRoot == nullptr) {
				if (t != nullptr) {
					loopRoot = t;
					loopLen = v->loopLen;
				}
			} else if ((t != nullptr) && (t->depth <= loopRoot->depth)) {
				loopRoot = t;
				loopLen = v->loopLen;
			}
		}
	}
	return loopRoot;
}

uint32_t calc_dist_root_loop(GVertex *v) {
	assert (v->loopRoot != nullptr);
		uint32_t d1 = v->depth - v->loopRoot->depth;
		uint32_t d2 = v->loopLen - d1;
		uint32_t d = std::max(d1, d2);

		//std::cerr << d1 << " " << d2 << "\n";

		if (v->loopRoot->loopRoot == v->loopRoot) {
			return d;
		} else {
			return calc_dist_root_loop(v->loopRoot) + d;
		}
}

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);
	uint32_t vCnt, eCnt, sInd, eInd;

	std::cin >> vCnt >> eCnt >> sInd >> eInd;
	graph.resize(vCnt);

	start = &graph[sInd - 1];
	end = &graph[eInd - 1];

	for (uint32_t i = 0;i < eCnt;i++) {
		uint32_t a, b;
		std::cin >> a >> b;
		a--;
		b--;
		graph[a].edges.push_back(&graph[b]);
		graph[b].edges.push_back(&graph[a]);
	}
}

int main () {
	input();
	start->depth = 1;
	start->dfs();
//	std::cerr << "---\n";
//	for (uint32_t i = 0;i < graph.size();i++) {
//		std::cerr << i + 1 << " " << graph[i].depth << " " << graph[i].loopRoot - &graph[0] + 1;
//		std::cerr << " " << graph[i].loopLen << "\n";
//	}
//
//	std::cerr << "---\n";
	uint32_t ans = calc_dist_root_loop(end);
	std::cout << ans << "\n";
}
