#include <iostream>
#include <cstdint>
#include <stack>
#include <vector>
#include <algorithm>

struct AnsEntry {
	uint32_t s, e;
	std::vector<uint32_t> ind;
};

std::string br;
uint32_t spl;

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);
	std::cin >> br;
	std::cin >> spl;
}

AnsEntry build_ans_entry(uint32_t s, uint32_t e) {
	std::stack<uint32_t> op;
	AnsEntry ans;
	ans.s = s + 1;
	ans.e = e + 1;
	for (uint32_t i = s;i <= e;i++) {
		if (br[i] == '(') {
			op.push(i);
		} else {
			if (!op.empty()) {
				ans.ind.push_back(op.top() + 1);
				ans.ind.push_back(i + 1);
				op.pop();
			}
		}
	}
	return ans;
}

std::pair<uint32_t, uint32_t> closest_end(uint32_t s, uint32_t maxE, bool rev) {
	uint32_t bestFuckedUp = 0;
	uint32_t bestEnd = s;

	std::stack<uint32_t> op;
	uint32_t ogr = rev ? maxE - 1 : maxE + 1;
	uint32_t step = rev ? (uint32_t)(-1) : 1U;
	char openBr = rev ? ')' : '(';

	for (uint32_t i = s;i != ogr;i += step) {
		if (br[i] == openBr) {
			op.push(i);
		} else {
			if (!op.empty()) {
				op.pop();
			}
		}
		if (op.size() >= bestFuckedUp) {
			bestFuckedUp = op.size();
			bestEnd = i;
		}
	}
	return {bestEnd, bestFuckedUp};
}

std::vector<AnsEntry> solve_norm() {
	std::vector<AnsEntry> ans;
	uint32_t curStart = 0;
	for (uint32_t i = 0;i + 1 < spl;i++) {
		uint32_t maxE = br.size() - (spl - i - 1) - 1;
		auto p = closest_end(curStart, maxE, false);
		//std::cerr << "crr " << p.second << "\n";
		ans.push_back(build_ans_entry(curStart, p.first));
		curStart = p.first + 1;
	}
	ans.push_back(build_ans_entry(curStart, br.size() - 1));
	return ans;
}

std::vector<AnsEntry> solve_rev() {
	std::vector<AnsEntry> ans;
	uint32_t curStart = br.size() - 1;
	for (uint32_t i = 0;i + 1 < spl;i++) {
		uint32_t maxE = spl - i - 1;
		auto p = closest_end(curStart, maxE, true);
		//std::cerr << "crr " << p.second << "\n";
		ans.push_back(build_ans_entry(p.first, curStart));
		curStart = p.first - 1;
	}
	ans.push_back(build_ans_entry(0, curStart));
	std::reverse(ans.begin(), ans.end());
	return ans;
}

void print_ans(const std::vector<AnsEntry> &ans) {
	for (uint32_t i = 0;i < ans.size();i++) {
		std::cout << i + 1 << ",[" << ans[i].s << "," << ans[i].e << "],";
		std::cout << ans[i].ind.size() << ":";
		for (uint32_t j : ans[i].ind) {
			std::cout << j << " ";
		}
		std::cout << "\n";
	}
}

uint32_t deduce_len(const std::vector<AnsEntry> &ans) {
	uint32_t l = 0;
	for (const auto &i : ans){ 
		l += i.ind.size();
	}
	return l;
}

int main() {
	input();
	std::vector<AnsEntry> rAns = solve_rev();
	std::vector<AnsEntry> nAns = solve_norm();
	uint32_t len = deduce_len(rAns);

	std::cout << len << "\n";
	print_ans(rAns);
	print_ans(nAns);
	

}


