#include <iostream>
#include <cstdint>
#include <stack>
#include <vector>
#include <algorithm>
#include <cstring>

struct AnsEntry {
	uint32_t s, e;
	std::vector<uint32_t> ind;
};

struct SegAns {
	uint32_t minInd, maxInd;
	uint32_t val;

	static SegAns combine(const SegAns &a1, const SegAns &a2) {
		if (a1.val == a2.val) {
			SegAns ans;
			ans.val = a1.val;
			ans.minInd = std::min(a1.minInd, a2.minInd);
			ans.maxInd = std::max(a1.maxInd, a2.maxInd);
			return ans;
		} else {
			return a2.val < a1.val ? a2 : a1;
		}
	}
};

template <size_t N>
struct SegmentTree {
	SegAns data[N * 2];
	uint32_t lazy[N];

	inline void upd_val(uint32_t n, uint32_t v) {
		data[n].val += v;
		if (n < N) {
			lazy[n] += v;
		}
	}

	inline void reeval(uint32_t n) {
		data[n].val = std::min(data[n * 2].val, data[n * 2 + 1].val);

		if (data[n * 2].val == data[n].val) {
			data[n].minInd = data[n * 2].minInd;
		} else {
			data[n].minInd = data[n * 2 + 1].minInd;
		}

		if (data[n * 2 + 1].val == data[n].val) {
			data[n].maxInd = data[n * 2 + 1].maxInd;
		} else {
			data[n].maxInd = data[n * 2].maxInd;
		}

		data[n].val += lazy[n];
	}

	inline void push_lazy(uint32_t n) {
		for (uint32_t i = lvl;i > 0;i--) {
			uint32_t c = n >> i;
			if (c == 0) {
				continue;
			}
			if (lazy[c]) {
				upd_val(2 * c, lazy[c]);
				upd_val(2 * c ^ 1, lazy[c]);
				lazy[c] = 0;
			}
		}
	}
	inline void push_updates(uint32_t n) {
		for (n >>= 1;n > 0;n >>= 1) {
			reeval(n);
		}
	}

	uint32_t lvl;
	SegmentTree() {
		lvl = 0;
		while (((N * 2 - 1) >> (lvl + 1)) > 0) {
			lvl++;
		}
	}

	void clear() {
		for (uint32_t i = 0;i < N;i++) {
			lazy[i] = 0;
			data[i + N].minInd = data[i + N].maxInd = i;
		}
		for (uint32_t i = 0;i < 2 * N;i++) {
			data[i].val = 0;
		}
	}

	void update(uint32_t l, uint32_t r, uint32_t v) {
		l += N;
		r += N;
		uint32_t oL = l;
		uint32_t oR = r;

		//not sure if necessary
		push_lazy(oL);
		push_lazy(oR - 1);

		for (;l < r;l >>= 1, r >>= 1) {
			if (l & 1) {
				upd_val(l++, v);
			}
			if (r & 1) {
				upd_val(--r, v);
			}
		}
		push_updates(oL);
		push_updates(oR - 1);
	}

	SegAns query(uint32_t l, uint32_t r) {
		l += N;
		r += N;

		push_lazy(l);
		push_lazy(r - 1);
		SegAns ans = data[l];
		for (;l < r;l >>= 1, r >>= 1) {
			if (l & 1) {
				ans = SegAns::combine(data[l++], ans);
			}
			if (r & 1) {
				ans = SegAns::combine(data[--r], ans);
			}
		}
		return ans;
	}
};


std::string br;
uint32_t spl;
std::vector<uint32_t> opInd;

typedef uint32_t cigari;

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);
	std::cin >> br;
	std::cin >> spl;
}

void build_op_ind() {
	std::stack<cigari> op;
	opInd.resize(br.size());
	for (uint32_t i = 0;i < br.size();i++) {
		opInd[i] = br.size();
		if (br[i] == '(') {
			op.push(i);
		} else {
			if (!op.empty()) {
				opInd[i] = op.top();
				op.pop();
			}
		}
	}
}

const uint32_t MAX_N = 1000;
const uint32_t MAX_K = 200;

SegAns dp[MAX_K + 1][MAX_N + 1];
SegmentTree<MAX_N + 10> dpSeg;

std::ostream& operator<< (std::ostream &s, const SegAns &a) {
	return s << a.val << "[" << a.minInd << "," << a.maxInd << "]";
}

void calc_dp() {
	//std::memset(dp, (uint32_t)(-1), sizeof(dp));
	for (uint32_t i = 0;i <= br.size();i++) {
		dp[0][i].val = 1e9;
	}
	dp[0][0].val = 0;
	for (uint32_t s = 1;s <= spl;s++) {
		dpSeg.clear();
		for (uint32_t i = 0;i <= br.size();i++) {
			dpSeg.update(i, i + 1, dp[s - 1][i].val);
		}

		for (uint32_t i = 1;i <= br.size();i++) {
			if ((br[i - 1] == ')') && (opInd[i - 1] < br.size())) {
				dpSeg.update(0, opInd[i - 1] + 1, 2);
			} 
			dp[s][i] = dpSeg.query(0, i);
		}
	}

	for (uint32_t s = 1;s <= spl;s++) {
		for (uint32_t i = 0;i <= br.size();i++) {
			std::cerr << dp[s][i] << " ";
		}
		std::cerr << "\n";
	}
}

AnsEntry build_ans_entry(uint32_t s, uint32_t e) {
	std::stack<cigari> op;
	AnsEntry ans;
	ans.s = s + 1;
	ans.e = e + 1;
	for (uint32_t i = s;i <= e;i++) {
		if (br[i] == '(') {
			op.push(i);
		} else {
			if (!op.empty()) {
				ans.ind.push_back(op.top() + 1);
				ans.ind.push_back(i + 1);
				op.pop();
			}
		}
	}
	return ans;
}

std::vector<AnsEntry> recover_ans(bool maxAns) {
	uint32_t curInd = br.size();
	std::vector<AnsEntry> ans;
	for (uint32_t i = spl;i > 0;i--) {
		uint32_t pInd;
		if (maxAns) {
			pInd = dp[i][curInd].maxInd;
		} else {
			pInd = dp[i][curInd].minInd;
		}

		//std::cerr << pInd << " " << curInd - 1 << "\n";
		ans.push_back(build_ans_entry(pInd, curInd - 1));
		curInd = pInd;
	}
	std::reverse(ans.begin(), ans.end());
	//ans[0].s = 1;
	return ans;
}

void print_ans(const std::vector<AnsEntry> &ans) {
	for (uint32_t i = 0;i < ans.size();i++) {
		std::cout << i + 1 << ",[" << ans[i].s << "," << ans[i].e << "],";
		std::cout << ans[i].ind.size() << ":";
		for (uint32_t j : ans[i].ind) {
			std::cout << j << " ";
		}
		std::cout << "\n";
	}
}

uint32_t deduce_len(const std::vector<AnsEntry> &ans) {
	uint32_t l = 0;
	for (const auto &i : ans){ 
		l += i.ind.size();
	}
	return l;
}

int main() {
	input();
	build_op_ind();
	calc_dp();
	std::cout << dp[spl][br.size()].val << "\n";
	//std::cerr << dp[spl][br.size()].minInd << " " << dp[spl][br.size()].minInd << "\n";

	print_ans(recover_ans(false));
	print_ans(recover_ans(true));

}


