#include <iostream>
#include <vector>
#include <cstdint>
#include <utility>
#include <algorithm>
#include <random>

struct Vector {
	int32_t x, y;
	Vector(int32_t pX = 0, int32_t pY = 0): x(pX), y(pY) {}

	friend Vector operator+ (const Vector &v1, const Vector &v2) {
		return Vector(v1.x + v2.x, v1.y + v2.y);
	}
	friend Vector operator- (const Vector &v1, const Vector &v2) {
		return Vector(v1.x - v2.x, v1.y - v2.y);
	}
	friend Vector operator* (const Vector &v, int32_t a) {
		return Vector(v.x * a, v.y * a);
	}
	friend int64_t operator* (const Vector &v1, const Vector &v2) {
		return (int64_t) v1.x * v2.y - (int64_t) v1.y * v2.x;
	}

	friend bool operator< (const Vector &a, const Vector &b) {
		return atan2(a.y, a.x) < atan2(b.y, b.x);
	}

	static Vector reflect (const Vector &a, const Vector &b) {
		return b * 2 - a;
	}

};

std::vector<std::pair<Vector, uint32_t>> points;
std::vector<std::pair<uint32_t, uint32_t>> ans;

std::mt19937 rand_gen(0xCAFEBABE);

void sort_points() {
	Vector vMin = points[0].first;
	for (auto p : points) {
		if ((p.first.y < vMin.y) || ((p.first.y == vMin.y) && (p.first.x < vMin.x))) {
			vMin = p.first;
		}
	}
	for (auto &p : points) {
		p.first = p.first - vMin;
	}

	std::sort(points.begin(), points.end());
}

bool mutate() {
	sort_points();
	//std::cerr << "h\n";

	
	/*for (auto p : points) {
		std::cerr << p.first.x << " " << p.first.y << "\n";
	}*/
	
	//return true;
	bool ok = true;
	uint32_t problemInd = 0;
	for (uint32_t i = 2;i < points.size();i++) {
		Vector v1 = points[i - 1].first - points[i - 2].first;
		Vector v2 = points[i].first - points[i - 1].first;
		if (v1 * v2 < 0) {
			ok = false;
			problemInd = i - 1;
			break;
		}
	}
	if (ok) {
		return true;
	}

	uint32_t rInd = problemInd;
	while (rInd == problemInd) {
		rInd = rand_gen() % points.size();
	}

	ans.push_back({points[problemInd].second, points[rInd].second});
	points[problemInd].first = Vector::reflect(points[problemInd].first, points[rInd].first);
	return false;
}

void input() {
	std::ios::sync_with_stdio(false);
	std::cin.tie(nullptr);
	uint32_t pCnt;
	std::cin >> pCnt;

	points.resize(pCnt);
	for (uint32_t i = 0;i < pCnt;i++) {
		std::cin >> points[i].first.x >> points[i].first.y;
		points[i].second = i + 1;
	}
}	

int main() {
	input();
	while (!mutate());
	std::cout << ans.size() << "\n";
	for (const auto &p : ans) {
		std::cout << p.first << " " << p.second << "\n";
	}

}
