#include<iostream>
#include<vector>
#include<algorithm>
#include<math.h>
using namespace std;

const int MAX_N=128;

struct Point
{
    double x;
    double y;
    int on;
};

struct Jump
{
    int a;
    int b;
};
struct Matrix
{
    double a[2][2];
    void multrow(int r, double k)
    {
        a[r][0]*=k;
        a[r][1]*=k;
    }
    void addrow(int r1, int r2, double k)
    {
        a[r1][0]+=k*a[r2][0];
        a[r1][1]+=k*a[r2][1];
    }
    Matrix inverse()
    {
        Matrix b;
        b.a[0][0]=1;
        b.a[1][1]=1;
        b.a[0][1]=0;
        b.a[1][0]=0;
        b.multrow(0,1/a[0][0]);
        multrow(0,1/a[0][0]);
        b.addrow(1,0,-a[1][0]);
        addrow(1,0,-a[1][0]);
        b.multrow(1,1/a[1][1]);
        multrow(1,1/a[1][1]);
        b.addrow(0,1,-a[0][1]);
        addrow(0,1,-a[0][1]);
        return b;
    }
};
Point operator+(const Point& p1, const Point& p2)
{
    Point p;
    p.on=p1.on;
    p.x=p1.x+p2.x;
    p.y=p1.y+p2.y;
    return p;
}
Point operator-(const Point& p1, const Point& p2)
{
    Point p;
    p.on=p1.on;
    p.x=p1.x-p2.x;
    p.y=p1.y-p2.y;
    return p;
}
void jump(Point& j, const Point& p)
{
    j.x=2*p.x-j.x;
    j.y=2*p.y-j.y;
}
Point operator*(const Matrix& m, const Point& p)
{
    Point p2;
    p2.on=p.on;
    p2.x=p.x*m.a[0][0]+p.y*m.a[0][1];
    p2.y=p.x*m.a[1][0]+p.y*m.a[1][1];
    return p2;
}
bool operator<(const Point& p1, const Point& p2)
{
    if (p1.x<p2.x) return 1;
    if (p1.x>p2.x) return 0;
    return p1.y<p2.y;
}
double get_slope(const Point& p1, const Point& p2)
{
    return (p2.y-p1.y)/(p2.x-p1.x);
}

int n;
Point p[MAX_N];
vector<Jump> j;

void input()
{
    cin>>n;
    for (int i=0;i<n;++i)
    {
        p[i].on=i+1;
        cin>>p[i].x>>p[i].y;
    }
}
void output()
{
    cout<<j.size()<<'\n';
    for (int i=0;i<j.size();++i)
    {
        cout<<j[i].a<<' '<<j[i].b<<'\n';
    }
}
double mind=-1;
int a,b;
void find_closest()
{
    int cd;
    for (int i=0;i<n;++i)
    {
        for (int j=i+1;j<n;++j)
        {
            cd=(p[i].x-p[j].x)*(p[i].x-p[j].x)+(p[i].y-p[j].y)*(p[i].y-p[j].y);
            if (mind==-1 || cd<mind)
            {
                mind=cd;
                a=i;
                b=j;
            }
        }
    }
}
Matrix m;
Point shift;
void get_matrix_and_shift()
{
    double ix,iy,jx,jy;
    jx=p[b].x-p[a].x;
    jy=p[b].y-p[a].y;
    iy=-jx;
    ix=jy;
    m.a[0][0]=ix;
    m.a[1][0]=iy;
    m.a[0][1]=jx;
    m.a[1][1]=jy;
    /*cerr<<"matrix:\n";
    cerr<<m.a[0][0]<<" "<<m.a[0][1]<<endl;
    cerr<<m.a[1][0]<<" "<<m.a[1][1]<<endl<<endl;*/
    m=m.inverse();
    /*cerr<<"inverse:\n";
    cerr<<m.a[0][0]<<" "<<m.a[0][1]<<endl;
    cerr<<m.a[1][0]<<" "<<m.a[1][1]<<endl<<endl;*/
    Point zero;
    zero.x=0;
    zero.y=0;
    shift=zero-p[a];
    shift=m*shift;
}
void change_basis_and_shift()
{
    get_matrix_and_shift();
    for (int i=0;i<n;++i)
    {
        p[i]=m*p[i]+shift;
    }
    /*cerr<<endl;
    for (int i=0;i<n;++i)
    {
        cerr<<p[i].x<<" "<<p[i].y<<" "<<p[i].on<<endl;
    }*/
}
void first_jumps() //all xs become positive
{
    for (int i=0;i<n;++i)
    {
        if (i==a || i==b) continue;
        if (p[i].x<0)
        {
            j.push_back({p[i].on,p[a].on});
            jump(p[i],p[a]);
        }
    }
    /*cerr<<endl;
    for (int i=0;i<n;++i)
    {
        cerr<<p[i].x<<" "<<p[i].y<<" "<<p[i].on<<endl;
    }*/
}
void find_ab()
{
    for (int i=0;i<n;++i)
    {
        if (p[i].on==a+1)
        {
            a=i;
            break;
        }
    }
    for (int i=0;i<n;++i)
    {
        if (p[i].on==b+1)
        {
            b=i;
            break;
        }
    }
}
void jumps()
{
    Point last={0,0,-1};
    double target_slope=-100;
    double curr_slope;
    int c;
    for (int i=0;i<n;++i)
    {
        if (i==a || i==b) continue;
        curr_slope=get_slope(last,p[i]);
        if (curr_slope<target_slope)
        {
            while(curr_slope<target_slope)
            {
                jump(p[i],p[a]);
                j.push_back({p[i].on,p[a].on});
                jump(p[i],p[b]);
                j.push_back({p[i].on,p[b].on});
                curr_slope=get_slope(last,p[i]);
            }
        }
        else
        {
            c=0;
            while(curr_slope>=target_slope)
            {
                ++c;
                jump(p[i],p[b]);
                jump(p[i],p[a]);
                curr_slope=get_slope(last,p[i]);
            }
            --c;
            jump(p[i],p[a]);
            jump(p[i],p[b]);
            for (int k=0;k<c;++k)
            {
                j.push_back({p[i].on,p[b].on});
                j.push_back({p[i].on,p[a].on});
            }
        }
        target_slope=get_slope(last,p[i]);
        last=p[i];
        //cerr<<"jumped to: "<<p[i].x<<" "<<p[i].y<<" "<<p[i].on<<" ts: "<<target_slope<<endl;
    }
}
void solve()
{
    find_closest();
    change_basis_and_shift();
    first_jumps();
    sort(p,p+n);
    /*cerr<<endl;
    for (int i=0;i<n;++i)
    {
        cerr<<p[i].x<<" "<<p[i].y<<" "<<p[i].on<<endl;
    }*/
    find_ab();
    jumps();
    /*cerr<<endl;
    for (int i=0;i<n;++i)
    {
        cerr<<p[i].x<<" "<<p[i].y<<" "<<p[i].on<<endl;
    }
    cerr<<endl;*/
}

int main()
{
    cin.tie(0);
    ios::sync_with_stdio(0);

    input();
    solve();
    output();

    return 0;
}
